xila_file_system_directory_close

Function xila_file_system_directory_close 

pub unsafe extern "C" fn xila_file_system_directory_close(
    directory: *mut XilaFileSystemDirectory,
) -> XilaFileSystemResult
This function is used to close a directory.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized `XilaFile