xila_file_system_directory_get_state

Function xila_file_system_directory_get_state 

pub unsafe extern "C" fn xila_file_system_directory_get_state(
    directory: *mut XilaFileSystemDirectory,
    state: *mut u8,
) -> XilaFileSystemResult
This function is used to get the state flags of a directory.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a directory.