xila_file_system_directory_set_position

Function xila_file_system_directory_set_position 

pub unsafe extern "C" fn xila_file_system_directory_set_position(
    directory: *mut XilaFileSystemDirectory,
    offset: XilaFileSystemSize,
) -> XilaFileSystemResult
This function is used to set the position in a directory.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a directory.