xila_file_system_file_allocate

Function xila_file_system_file_allocate 

pub unsafe extern "C" fn xila_file_system_file_allocate(
    _file: *mut XilaFileSystemFile,
    _offset: XilaFileSystemSize,
    _length: XilaFileSystemSize,
) -> XilaFileSystemResult
This function is used to allocate space for a file.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a file.