xila_file_system_file_close

Function xila_file_system_file_close 

pub unsafe extern "C" fn xila_file_system_file_close(
    file: *mut XilaFileSystemFile,
) -> XilaFileSystemResult
This function is used to close a file.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a file.

Errors

This function may return an error if the file system fails to close the file.