xila_file_system_file_read

Function xila_file_system_file_read 

pub unsafe extern "C" fn xila_file_system_file_read(
    file: *mut XilaFileSystemFile,
    buffers: *const *mut u8,
    buffers_length: *const usize,
    buffer_count: usize,
    read: *mut usize,
) -> XilaFileSystemResult
This function is used to perform a write operation on a file.

Safety

This function is unsafe because it dereferences raw pointers.

Errors

This function may return an error if the file system fails to open the file.