xila_file_system_file_truncate

Function xila_file_system_file_truncate 

pub unsafe extern "C" fn xila_file_system_file_truncate(
    _file: *mut XilaFileSystemFile,
    _length: XilaFileSystemSize,
) -> XilaFileSystemResult
This function is used to set the position in a file.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a file.