xila_file_system_get_access_flags

Function xila_file_system_get_access_flags 

pub unsafe extern "C" fn xila_file_system_get_access_flags(
    file: XilaFileIdentifier,
    mode: *mut XilaFileSystemMode,
) -> XilaFileSystemResult
This function is used to get the access mode of a file.

Safety

This function is unsafe because it dereferences raw pointers.

Errors

This function may return an error if the file system fails to get the access mode of the file.