xila_file_system_get_statistics_from_path

Function xila_file_system_get_statistics_from_path 

pub unsafe extern "C" fn xila_file_system_get_statistics_from_path(
    path: *const c_char,
    statistics: *mut XilaFileSystemStatistics,
) -> XilaFileSystemResult
This function is used to get statistics for a path.

Safety

This function is unsafe because it dereferences raw pointers.