xila_file_system_set_times

Function xila_file_system_set_times 

pub unsafe extern "C" fn xila_file_system_set_times(
    _file: *mut XilaFileSystemFile,
    _access: XilaTime,
    _modification: XilaTime,
    _flags: u8,
) -> XilaFileSystemResult
This function is used to advice the file system about the access pattern of a file.

Safety

The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a file.