xila_network_receive

Function xila_network_receive 

pub unsafe extern "C" fn xila_network_receive(
    _socket: XilaFileSystemFile,
    buffer: *mut u8,
    size: usize,
) -> XilaFileSystemResult
This function is used to receive data through a socket.

Safety

This function is unsafe because it dereferences raw pointers.

Errors

This function may return an error if the file system fails to receive the data.