pub unsafe extern "C" fn xila_file_system_dummy(
_event: XilaFileSystemPollEvent,
) -> XilaFileSystemResultExpand description
This function is used to perform a poll operation on a file.
Safety
The caller must ensure that the provided pointer is valid and points to a properly initialized XilaFileSystemItem that is a file.