pub unsafe extern "C" fn xila_file_system_file_flush(
file: *mut XilaFileSystemFile,
_t: bool,
) -> XilaFileSystemResultExpand description
This function is used to flush a file.
Safety
The caller must ensure that the provided pointer is valid and points to a properly initialized `XilaFile