pub unsafe extern "C" fn xila_file_system_file_read_at(
file: *mut XilaFileSystemFile,
position: u64,
buffers: *const *mut u8,
buffers_length: *const usize,
buffer_count: usize,
read: *mut usize,
) -> XilaFileSystemResultExpand description
This function is used to perform a read operation on a file at a specific position.
Safety
This function is unsafe because it dereferences raw pointers.